@@ -1,6 +1,6 @@
 {-
    ExtractContours.hs (adapted from tess.c which is (c) Silicon Graphics, Inc)
-   Copyright (c) Sven Panne 2002-2005 <sven.panne@aedion.de>
+   Copyright (c) Sven Panne 2002-2005 <svenpanne@gmail.com>
    This file is part of HOpenGL and distributed under a BSD-style license
    See the file libraries/GLUT/LICENSE
 
@@ -23,7 +23,7 @@ display displayLists = do
    -- resolve overloading, not needed in "real" programs
    let color3f = color :: Color3 GLfloat -> IO ()
    color3f (Color3 1 1 1)
-   mapM callList displayLists
+   mapM_ callList displayLists
    flush
 
 -- 'Float' is a dummy, any marshalable type would do
@@ -109,7 +109,7 @@ main = do
    (progName, _args) <- getArgsAndInitialize
    initialDisplayMode $= [ SingleBuffered, RGBMode ]
    initialWindowSize $= Size 500 500
-   createWindow progName
+   _ <- createWindow progName
    displayLists <- myInit
    displayCallback $= display displayLists
    reshapeCallback $= Just reshape
